@@ -1,28 +1,28 @@
 
 /*
- *  $Id: defLex.c,v 4.12 2006/03/25 19:24:49 bkorb Exp $
+ *  $Id: defLex.c,v 4.21 2007/07/04 20:51:11 bkorb Exp $
+ *
+ *  Time-stamp:        "2007-07-04 11:16:53 bkorb"
+ *  Last Committed:    $Date: 2007/07/04 20:51:11 $
+ *
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
- */
-
-/*
- *  AutoGen copyright 1992-2006 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 tSCC zErrMsg[] = "%s Error:  %s in %s on line %d\n";
 
@@ -44,7 +44,7 @@ tSCC*  apzKeywords[] = { KEYWORD_TABLE };
 #undef _KW_
 
 #define _KW_(w) DP_EV_ ## w,
-int    aKeywordTkn[] = { KEYWORD_TABLE };
+te_dp_event aKeywordTkn[] = { KEYWORD_TABLE };
 #undef _KW_
 
 #define KEYWORD_CT  (sizeof( apzKeywords ) / sizeof( apzKeywords[0] ))
@@ -179,7 +179,7 @@ scanAgain:
         break;
 
     case '\\':
-        if (strncmp( pCurCtx->pzScan+1, "'(", 2) == 0) {
+        if (strncmp( pCurCtx->pzScan+1, "'(", (size_t)2) == 0) {
             alist_to_autogen_def();
             goto scanAgain;
 
@@ -219,7 +219,7 @@ scanAgain:
             pzShellProgram = getDefine( zShellEnv, AG_TRUE );
 
         lastToken = DP_EV_STRING;
-        pz = runShell( (const char*)pz_token );
+        pz = runShell( (char const*)pz_token );
         if (pz == NULL)
             goto scanAgain;
         TAGMEM( pz, "shell definition string" );
@@ -277,23 +277,19 @@ NUL_error:
     return DP_EV_INVALID;
 
 lex_done:
-    {
-        tSCC zDone[] = "";
+    /*
+     *  First time through, return the DP_EV_END token.
+     *  Second time through, we really finish.
+     */
+    if (pCurCtx->pzScan == zNil) {
+        pCurCtx->pCtx = pDoneCtx;
+        pDoneCtx      = pCurCtx;
 
-        /*
-         *  First time through, return the DP_EV_END token.
-         *  Second time through, we really finish.
-         */
-        if (pCurCtx->pzScan == zDone) {
-            pCurCtx->pCtx = pDoneCtx;
-            pDoneCtx      = pCurCtx;
-
-            return DP_EV_INVALID;
-        }
-
-        pCurCtx->pzScan = (char*)zDone;
-        return DP_EV_END;
+        return DP_EV_INVALID;
     }
+
+    pCurCtx->pzScan = (char*)zNil;
+    return DP_EV_END;
 }
 
 
@@ -353,7 +349,7 @@ loadScheme( void )
     *pzEnd = endCh;
 
     pCurCtx->pzScan = pzEnd;
-    pzEnd = resolveSCM( res );
+    pzEnd = (char*)resolveSCM( res ); /* ignore const-ness */
     if (strlen( pzEnd ) >= schemeLen) {
         AGDUPSTR( pzEnd, pzEnd, "SCM Result" );
 
@@ -386,7 +382,7 @@ alist_to_autogen_def( void )
     char*  pzEnd   = (char*)skipScheme( pzText, pzText + strlen( pzText ));
 
     SCM    res;
-    int    res_len;
+    size_t res_len;
     tScanCtx*  pCtx;
 
     /*
@@ -546,7 +542,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
                 /*
                  *  Return the keyword token code instead of DP_EV_NAME
                  */
-                *pRetVal = (te_dp_event)aKeywordTkn[ kw_ix ];
+                *pRetVal = aKeywordTkn[ kw_ix ];
                 break;
             }
         } while (++kw_ix < KEYWORD_CT);
@@ -568,7 +564,7 @@ assembleHereString( char* pzScan )
 {
     ag_bool  trimTabs = AG_FALSE;
     char     zMark[ MAX_HEREMARK_LEN ];
-    int      markLen = 0;
+    size_t   markLen = 0;
     char*    pzDest;
 
     /*
@@ -664,7 +660,6 @@ assembleHereString( char* pzScan )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/defLex.c */
