@@ -1,38 +1,44 @@
 
 /*
  *  expString.c
- *  $Id: expString.c,v 4.10 2006/06/24 23:36:07 bkorb Exp $
+ *  $Id: expString.c,v 4.20 2007/07/07 01:04:11 bkorb Exp $
+ *
+ *  Time-stamp:        "2007-07-06 13:34:10 bkorb"
+ *  Last Committed:    $Date: 2007/07/07 01:04:11 $
+ *
  *  This module implements expression functions that
  *  manipulate string values.
- */
-
-/*
- *  AutoGen copyright 1992-2006 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *  See the GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
+static size_t
+string_size(char const * pzScn, size_t newLineSize);
+
 static SCM
 makeString( tCC*    pzText,
             tCC*    pzNewLine,
             size_t  newLineSize );
 
+static size_t
+stringify_for_shell(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize);
+
 static SCM
 shell_stringify( SCM obj, u_int qt );
 
@@ -53,20 +59,13 @@ do_multi_subs(
     SCM         repl );
 /* = = = END-STATIC-FORWARD = = = */
 
-static SCM
-makeString( tCC*    pzText,
-            tCC*    pzNewLine,
-            size_t  newLineSize )
+static size_t
+string_size(char const * pzScn, size_t newLineSize)
 {
-    char     z[ 256 ];
-    char*    pzDta;
-    char*    pzFre;
-    tCC*     pzScn   = pzText;
-
     /*
      *  Start by counting the start and end quotes, plus the NUL.
      */
-    size_t   dtaSize = sizeof( "\"\"" );
+    size_t dtaSize = sizeof( "\"\"" );
 
     for (;;) {
         char ch = *(pzScn++);
@@ -86,7 +85,7 @@ makeString( tCC*    pzText,
          */
         else switch (ch) {
         case NUL:
-            goto loopBreak;
+            return dtaSize;
 
         case '\n':
             dtaSize += newLineSize;
@@ -104,7 +103,19 @@ makeString( tCC*    pzText,
         default:
             dtaSize += 4;
         }
-    } loopBreak:;
+    }
+}
+
+static SCM
+makeString( tCC*    pzText,
+            tCC*    pzNewLine,
+            size_t  newLineSize )
+{
+    char     z[ 256 ];
+    char*    pzDta;
+    char*    pzFre;
+    tCC*     pzScn   = pzText;
+    size_t   dtaSize = string_size(pzText, newLineSize);
 
     /*
      *  We now know how big the string is going to be.
@@ -114,8 +125,6 @@ makeString( tCC*    pzText,
          pzFre = pzDta = AGALOC( dtaSize, "quoting string" );
     else pzFre = pzDta = z;
 
-    pzScn = pzText;
-
     *(pzDta++) = '"';
 
     for (;;) {
@@ -220,97 +229,94 @@ makeString( tCC*    pzText,
     }
 }
 
+static size_t
+stringify_for_shell(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize)
+{
+    char * pz = pzNew;
+    *(pz++) = qt;
+
+    for (;;) {
+        char c = (*(pz++) = *(pzDta++));
+        switch (c) {
+        case NUL:
+            pz[-1]  = qt;
+            *pz     = NUL;
+            dtaSize = (pz - pzNew);
+
+            return (pz - pzNew);
+
+        case '\\':
+            /*
+             *  If someone went to the trouble to escape a backquote or a
+             *  dollar sign, then we should not neutralize it.  Note that
+             *  we handle a following backslash as a normal character.
+             *
+             *  i.e.  \\ --> \\\\ *BUT* \\$ --> \\\$
+             */
+            c = *pzDta;
+            switch (*pzDta) {
+            case '$':
+                break;
+
+            case '"':
+            case '`':
+                /*
+                 *  IF the ensuing quote character does *NOT* match the
+                 *  quote character for the string, then we will preserve
+                 *  the single copy of the backslash.  If it does match,
+                 *  then we will double the backslash and a third backslash
+                 *  will be inserted when we emit the quote character.
+                 */
+                if (c != qt)
+                    break;
+                /* FALLTHROUGH */
+
+            default:
+                *(pz++) = '\\';   /* \   -->  \\    */
+            }
+            break;
+
+        case '"': case '`':
+            if (c == qt) {
+                /*
+                 *  This routine does both `xx` and "xx" strings, we have
+                 *  to worry about this stuff differently.  I.e., in ""
+                 *  strings, add a single \ in front of ", and in ``
+                 *  preserve a add \ in front of `.
+                 */
+                pz[-1]  = '\\';       /* "   -->   \"   */
+                *(pz++) = c;
+            }
+        }
+    }
+}
 
 static SCM
 shell_stringify( SCM obj, u_int qt )
 {
-    char*  pzDta;
     char*  pzNew;
     size_t dtaSize = 3;
+    char*  pzDta   = ag_scm2zchars( obj, "AG Object" );
+    char*  pz      = pzDta;
 
-    pzDta = ag_scm2zchars( obj, "AG Object" );
+    for (;;) {
+        char c = *(pz++);
 
-    {
-        char*  pz = pzDta;
+        switch (c) {
+        case NUL:
+            goto loopDone1;
 
-        for (;;) {
-            char c = *(pz++);
+        case '"': case '`': case '\\':
+            dtaSize += 2;
+            break;
 
-            switch (c) {
-            case NUL:
-                goto loopDone1;
-
-            case '"': case '`': case '\\':
-                dtaSize += 2;
-                break;
-
-            default:
-                dtaSize++;            
-            }
-        } loopDone1:;
-    }
+        default:
+            dtaSize++;
+        }
+    } loopDone1:;
 
     pzNew = AGALOC( dtaSize, "shell string" );
-
-    {
-        char* pz = pzNew;
-        *(pz++) = qt;
-
-        for (;;) {
-            char c = (*(pz++) = *(pzDta++));
-            switch (c) {
-            case NUL:
-                goto loopDone2;
-
-            case '\\':
-                /*
-                 *  If someone went to the trouble to escape a backquote or a
-                 *  dollar sign, then we should not neutralize it.  Note that
-                 *  we handle a following backslash as a normal character.
-                 *
-                 *  i.e.  \\ --> \\\\ *BUT* \\$ --> \\\$
-                 */
-                c = *pzDta;
-                switch (*pzDta) {
-                case '$':
-                    break;
-
-                case '"':
-                case '`':
-                    /*
-                     *  IF the ensuing quote character does *NOT* match the
-                     *  quote character for the string, then we will preserve
-                     *  the single copy of the backslash.  If it does match,
-                     *  then we will double the backslash and a third backslash
-                     *  will be inserted when we emit the quote character.
-                     */
-                    if (c != qt)
-                        break;
-                    /* FALLTHROUGH */
-
-                default:
-                    *(pz++) = '\\';   /* \   -->  \\    */
-                }
-                break;
-
-            case '"': case '`':
-                if (c == qt) {
-                    /*
-                     *  This routine does both `xx` and "xx" strings, we have
-                     *  to worry about this stuff differently.  I.e., in ""
-                     *  strings, add a single \ in front of ", and in ``
-                     *  preserve a add \ in front of `.
-                     */
-                    pz[-1]  = '\\';       /* "   -->   \"   */
-                    *(pz++) = c;
-                }
-            }
-        } loopDone2:;
-
-        pz[-1]  = qt;
-        *pz     = NUL;
-        dtaSize = (pz - pzNew);
-    }
+    dtaSize = stringify_for_shell(pzNew, qt, pzDta, dtaSize);
 
     {
         SCM res = AG_SCM_STR2SCM( pzNew, dtaSize );
@@ -370,10 +376,10 @@ do_substitution(
         if (pzNxt == NULL)
             break;
         if (pz != pzNxt) {
-            memcpy( pzScan, pz, (unsigned)(pzNxt - pz) );
+            memcpy( pzScan, pz, (size_t)(pzNxt - pz) );
             pzScan += (pzNxt - pz);
         }
-        memcpy( pzScan, pzRepl, (unsigned)replL );
+        memcpy( pzScan, pzRepl, (size_t)replL );
         pzScan += replL;
         pz = pzNxt + matchL;
     }
@@ -459,7 +465,7 @@ ag_scm_in_p( SCM obj, SCM list )
     int     len;
     size_t  lenz;
     SCM     car;
-    char*   pz1;
+    tCC *   pz1;
 
     if (! AG_SCM_STRING_P( obj ))
         return SCM_UNDEFINED;
@@ -531,7 +537,7 @@ ag_scm_join( SCM sep, SCM list )
     size_t     sep_len;
     scm_sizet  str_len;
     char*      pzRes;
-    char*      pzSep;
+    tCC *      pzSep;
     char*      pzScan;
 
     if (! AG_SCM_STRING_P( sep ))
@@ -539,7 +545,7 @@ ag_scm_join( SCM sep, SCM list )
 
     sv_l_len = l_len = scm_ilength( list );
     if (l_len == 0)
-        return AG_SCM_STR02SCM( "" );
+        return AG_SCM_STR02SCM(zNil);
 
     pzSep   = AG_SCM_CHARS( sep );
     sep_len = AG_SCM_STRLEN( sep );
@@ -1059,55 +1065,53 @@ ag_scm_c_string( SCM str )
 SCM
 ag_scm_string_tr_x( SCM str, SCM from_xform, SCM to_xform )
 {
-    {
-        char  map[ 256 ];
-        int   i = 255;
-        char* pzFrom = ag_scm2zchars( from_xform, "string" );
-        char* pzTo   = ag_scm2zchars(   to_xform, "string" );
+    char  map[ 256 ];
+    int   i = 255;
+    char* pzFrom = ag_scm2zchars( from_xform, "string" );
+    char* pzTo   = ag_scm2zchars(   to_xform, "string" );
 
-        do  {
-            map[i] = i;
-        } while (--i > 0);
+    do  {
+        map[i] = i;
+    } while (--i > 0);
 
-        for (;i <= 255;i++) {
-            unsigned char fch = (unsigned char)*(pzFrom++);
-            unsigned char tch = (unsigned char)*(pzTo++);
+    for (;i <= 255;i++) {
+        unsigned char fch = (unsigned char)*(pzFrom++);
+        unsigned char tch = (unsigned char)*(pzTo++);
 
-            if (tch == NUL) {
-                pzTo--;
-                tch = pzTo[-1];
-            }
-
-            switch (fch) {
-            case NUL:
-                goto mapDone;
-
-            case '-':
-                if ((i > 0) && (tch == '-')) {
-                    unsigned char fs = (unsigned char)pzFrom[-2];
-                    unsigned char fe = (unsigned char)pzFrom[0];
-                    unsigned char ts = (unsigned char)pzTo[-2];
-                    unsigned char te = (unsigned char)pzTo[0];
-                    if (te != NUL) {
-                        while (fs < fe) {
-                            map[ fs++ ] = ts;
-                            if (ts < te) ts++;
-                        }
-                        break;
-                    }
-                }
-
-            default:
-                map[ fch ] = tch;
-            }
-        } mapDone:;
-
-        pzTo = AG_SCM_CHARS( str );
-        i    = AG_SCM_STRLEN( str );
-        while (i-- > 0) {
-            *pzTo = map[ (int)*pzTo ];
-            pzTo++;
+        if (tch == NUL) {
+            pzTo--;
+            tch = pzTo[-1];
         }
+
+        switch (fch) {
+        case NUL:
+            goto mapDone;
+
+        case '-':
+            if ((i > 0) && (tch == '-')) {
+                unsigned char fs = (unsigned char)pzFrom[-2];
+                unsigned char fe = (unsigned char)pzFrom[0];
+                unsigned char ts = (unsigned char)pzTo[-2];
+                unsigned char te = (unsigned char)pzTo[0];
+                if (te != NUL) {
+                    while (fs < fe) {
+                        map[ fs++ ] = ts;
+                        if (ts < te) ts++;
+                    }
+                    break;
+                }
+            }
+
+        default:
+            map[ fch ] = tch;
+        }
+    } mapDone:;
+
+    pzTo = (char*)(void*)AG_SCM_CHARS( str );
+    i    = AG_SCM_STRLEN( str );
+    while (i-- > 0) {
+        *pzTo = map[ (int)*pzTo ];
+        pzTo++;
     }
     return str;
 }
@@ -1188,7 +1192,6 @@ ag_scm_string_substitute( SCM Str, SCM Match, SCM Repl )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expString.c */
