@@ -1,55 +1,32 @@
 
 /*
- *  $Id: pgusage.c,v 4.7 2006/03/25 19:24:56 bkorb Exp $
- * Time-stamp:      "2005-10-29 13:23:12 bkorb"
+ *  $Id: pgusage.c,v 4.14 2007/07/04 21:36:38 bkorb Exp $
+ * Time-stamp:      "2007-07-04 11:34:23 bkorb"
  *
  *   Automated Options Paged Usage module.
  *
  *  This routine will run run-on options through a pager so the
  *  user may examine, print or edit them at their leisure.
- */
-
-/*
- *  Automated Options copyright 1992-2006 Bruce Korb
  *
- *  Automated Options is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  Automated Options is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with Automated Options.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
  *
- * As a special exception, Bruce Korb gives permission for additional
- * uses of the text contained in his release of AutoOpts.
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
  *
- * The exception is that, if you link the AutoOpts library with other
- * files to produce an executable, this does not by itself cause the
- * resulting executable to be covered by the GNU General Public License.
- * Your use of that executable is in no way restricted on account of
- * linking the AutoOpts library code into it.
+ *  These files have the following md5sums:
  *
- * This exception does not however invalidate any other reasons why
- * the executable file might be covered by the GNU General Public License.
- *
- * This exception applies only to the code released by Bruce Korb under
- * the name AutoOpts.  If you copy code from other sources under the
- * General Public License into a copy of AutoOpts, as the General Public
- * License permits, the exception does not apply to the code that you add
- * in this way.  To avoid misleading anyone as to the status of such
- * modified files, you must delete this exception notice from them.
- *
- * If you write modifications of your own for AutoOpts, it is your choice
- * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
 tePagerState pagerState = PAGER_STATE_INITIAL;
@@ -68,6 +45,9 @@ tePagerState pagerState = PAGER_STATE_INITIAL;
 void
 optionPagedUsage( tOptions* pOptions, tOptDesc* pOD )
 {
+#if defined(__windows__) && !defined(__CYGWIN__)
+    (*pOptions->pUsageProc)( pOptions, EXIT_SUCCESS );
+#else
     static pid_t     my_pid;
     char zPageUsage[ 1024 ];
 
@@ -114,7 +94,7 @@ optionPagedUsage( tOptions* pOptions, tOptDesc* pOD )
     case PAGER_STATE_READY:
     {
         tSCC zPage[]  = "%1$s /tmp/use.%2$lu ; rm -f /tmp/use.%2$lu";
-        char* pzPager = getenv( "PAGER" );
+        tCC* pzPager  = (tCC*)getenv( "PAGER" );
 
         /*
          *  Use the "more(1)" program if "PAGER" has not been defined
@@ -133,7 +113,7 @@ optionPagedUsage( tOptions* pOptions, tOptDesc* pOD )
         fclose( stderr );
         dup2( STDOUT_FILENO, STDERR_FILENO );
 
-        system( zPageUsage );
+        (void)system( zPageUsage );
     }
 
     case PAGER_STATE_CHILD:
@@ -142,13 +122,13 @@ optionPagedUsage( tOptions* pOptions, tOptDesc* pOD )
          */
         break;
     }
+#endif
 }
 
 /*
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/pgusage.c */
