@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Sun Dec 17 12:01:41 PST 2006
+ * Generated Sat Jul 28 13:01:46 PDT 2007
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
 #define AUTOOPTS_PROTO_H_GUARD 1
@@ -72,6 +72,10 @@ loadOptionLine(
     tDirection  direction,
     tOptionLoadMode   load_mode );
 
+/*\n *  Extracted from nested.c\n */
+LOCAL tOptionValue*
+optionLoadNested(char const* pzTxt, char const* pzName, size_t nameLen);
+
 /*\n *  Extracted from sort.c\n */
 LOCAL void
 optionSort( tOptions* pOpts );
