@@ -1,53 +1,37 @@
 
 /*
- *  usage.c  $Id: usage.c,v 4.9 2005/11/07 00:22:05 bkorb Exp $
- * Time-stamp:      "2005-10-29 14:04:54 bkorb"
+ *  usage.c  $Id: usage.c,v 4.20 2007/07/16 00:17:31 bkorb Exp $
+ * Time-stamp:      "2007-07-15 09:43:04 bkorb"
  *
  *  This module implements the default usage procedure for
  *  Automated Options.  It may be overridden, of course.
+ *
+ *  Sort options:
+    --start=END-[S]TATIC-FORWARD --patt='^/\*($|[^:])' \
+    --out=xx.c key='^[a-zA-Z0-9_]+\(' --trail='^/\*:' \
+    --spac=2 --input=usage.c
  */
 
 /*
- *  Automated Options copyright 1992-2005 Bruce Korb
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  Automated Options is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
  *
- *  Automated Options is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
  *
- *  You should have received a copy of the GNU General Public License
- *  along with Automated Options.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
  *
- * As a special exception, Bruce Korb gives permission for additional
- * uses of the text contained in his release of AutoOpts.
+ *  These files have the following md5sums:
  *
- * The exception is that, if you link the AutoOpts library with other
- * files to produce an executable, this does not by itself cause the
- * resulting executable to be covered by the GNU General Public License.
- * Your use of that executable is in no way restricted on account of
- * linking the AutoOpts library code into it.
- *
- * This exception does not however invalidate any other reasons why
- * the executable file might be covered by the GNU General Public License.
- *
- * This exception applies only to the code released by Bruce Korb under
- * the name AutoOpts.  If you copy code from other sources under the
- * General Public License into a copy of AutoOpts, as the General Public
- * License permits, the exception does not apply to the code that you add
- * in this way.  To avoid misleading anyone as to the status of such
- * modified files, you must delete this exception notice from them.
- *
- * If you write modifications of your own for AutoOpts, it is your choice
- * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
 #define OPTPROC_L_N_S  (OPTPROC_LONGOPT | OPTPROC_SHORTOPT)
@@ -60,8 +44,8 @@ static ag_bool displayEnum;
 
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
-static void
-printProgramDetails( tOptions* pOptions );
+static ag_bool
+checkGNUUsage( tOptions* pOpts );
 
 static void
 printExtendedUsage(
@@ -70,30 +54,93 @@ printExtendedUsage(
     arg_types_t*  pAT );
 
 static void
-printBareUsage(
+printInitList(
+    tCC* const* papz,
+    ag_bool*    pInitIntro,
+    tCC*        pzRc,
+    tCC*        pzPN );
+
+static void
+printOneUsage(
     tOptions*     pOptions,
     tOptDesc*     pOD,
     arg_types_t*  pAT );
 
 static void
-setStdOptFmts( tOptions* pOpts, tCC** ppT );
+printOptionUsage(
+    tOptions* pOpts,
+    int       ex_code,
+    tCC*      pOptTitle );
 
 static void
+printProgramDetails( tOptions* pOptions );
+
+static int
 setGnuOptFmts( tOptions* pOpts, tCC** ppT );
 
-static void
-printInitList(
-    tCC**    papz,
-    ag_bool* pInitIntro,
-    tCC*     pzRc,
-    tCC*     pzPN );
+static int
+setStdOptFmts( tOptions* pOpts, tCC** ppT );
 /* = = = END-STATIC-FORWARD = = = */
 
+
+/*
+ *  Figure out if we should try to format usage text sort-of like
+ *  the way many GNU programs do.
+ */
+static ag_bool
+checkGNUUsage( tOptions* pOpts )
+{
+    char* pz = getenv( "AUTOOPTS_USAGE" );
+    if (pz == NULL)
+        ;
+
+    else if (streqvcmp( pz, "gnu" ) == 0)
+        pOpts->fOptSet |= OPTPROC_GNUUSAGE;
+
+    else if (streqvcmp( pz, "autoopts" ) == 0)
+        pOpts->fOptSet &= ~OPTPROC_GNUUSAGE;
+
+    return (pOpts->fOptSet & OPTPROC_GNUUSAGE) ? AG_TRUE : AG_FALSE;
+}
+
+
+/*=export_func  optionOnlyUsage
+ *
+ * what:  Print usage text for just the options
+ * arg:   + tOptions*   + pOpts    + program options descriptor +
+ * arg:   + int         + ex_code  + exit code for calling exit(3) +
+ *
+ * doc:
+ *  This routine will print only the usage for each option.
+ *  This function may be used when the emitted usage must incorporate
+ *  information not available to AutoOpts.
+=*/
+void
+optionOnlyUsage(
+    tOptions* pOpts,
+    int       ex_code )
+{
+    tCC* pOptTitle = NULL;
+
+    /*
+     *  Determine which header and which option formatting strings to use
+     */
+    if (checkGNUUsage(pOpts)) {
+        (void)setGnuOptFmts( pOpts, &pOptTitle );
+    }
+    else {
+        (void)setStdOptFmts( pOpts, &pOptTitle );
+    }
+
+    printOptionUsage( pOpts, ex_code, pOptTitle );
+}
+
+
 /*=export_func  optionUsage
  * private:
  *
  * what:  Print usage text
- * arg:   + tOptions* + pOpts    + program options descriptor +
+ * arg:   + tOptions* + pOptions + program options descriptor +
  * arg:   + int       + exitCode + exit code for calling exit(3) +
  *
  * doc:
@@ -101,13 +148,17 @@ printInitList(
  *  formats.  The descriptor specifies the default, but AUTOOPTS_USAGE will
  *  over-ride this, providing the value of it is set to either "gnu" or
  *  "autoopts".  This routine will @strong{not} return.
+ *
+ *  If "exitCode" is "EX_USAGE" (normally 64), then output will to to stdout
+ *  and the actual exit code will be "EXIT_SUCCESS".
 =*/
 void
 optionUsage(
     tOptions* pOptions,
-    int       exitCode )
+    int       usage_exit_code )
 {
-    tCC*    pOptTitle;
+    int actual_exit_code =
+        (usage_exit_code == EX_USAGE) ? EXIT_SUCCESS : usage_exit_code;
 
     displayEnum = AG_FALSE;
 
@@ -115,92 +166,64 @@ optionUsage(
      *  Paged usage will preset option_usage_fp to an output file.
      *  If it hasn't already been set, then set it to standard output
      *  on successful exit (help was requested), otherwise error out.
+     *
+     *  Test the version before obtaining pzFullUsage or pzShortUsage.
+     *  These fields do not exist before revision 30.
      */
-    if (option_usage_fp == NULL)
-        option_usage_fp = (exitCode != EXIT_SUCCESS) ? stderr : stdout;
+    {
+        char const * pz;
+
+        if (actual_exit_code == EXIT_SUCCESS) {
+            pz = (pOptions->structVersion >= 30 * 4096)
+                ? pOptions->pzFullUsage : NULL;
+
+            if (option_usage_fp == NULL)
+                option_usage_fp = stdout;
+        } else {
+            pz = (pOptions->structVersion >= 30 * 4096)
+                ? pOptions->pzShortUsage : NULL;
+
+            if (option_usage_fp == NULL)
+                option_usage_fp = stderr;
+        }
+
+        if (pz != NULL) {
+            fputs(pz, option_usage_fp);
+            exit(actual_exit_code);
+        }
+    }
 
     fprintf( option_usage_fp, pOptions->pzUsageTitle, pOptions->pzProgName );
 
-    do {
-        char* pz = getenv( "AUTOOPTS_USAGE" );
-        if (pz == NULL) break;
-        if (streqvcmp( pz, "gnu" ) == 0) {
-            pOptions->fOptSet |= OPTPROC_GNUUSAGE;
-            break;
-        }
-        if (streqvcmp( pz, "autoopts" ) == 0) {
-            pOptions->fOptSet &= ~OPTPROC_GNUUSAGE;
-            break;
-        }
-    } while (0);
-
-    /*
-     *  Determine which header and which option formatting strings to use
-     */
-    if ((pOptions->fOptSet & OPTPROC_GNUUSAGE) != 0) {
-        setGnuOptFmts( pOptions, &pOptTitle );
-        fputc( '\n', option_usage_fp );
-    }
-    else {
-        setStdOptFmts( pOptions, &pOptTitle );
+    {
+        tCC* pOptTitle = NULL;
 
         /*
-         *  When we exit with EXIT_SUCCESS and the first option is a doc option,
-         *  we do *NOT* want to emit the column headers.  Otherwise, we do.
+         *  Determine which header and which option formatting strings to use
          */
-        if (  (exitCode != EXIT_SUCCESS)
-           || ((pOptions->pOptDesc->fOptState & OPTST_DOCUMENT) == 0) )
-
-            fputs( pOptTitle, option_usage_fp );
-    }
-
-    {
-        int        ct     = pOptions->optCt;
-        int        optNo  = 0;
-        tOptDesc*  pOD    = pOptions->pOptDesc;
-        int        docCt  = 0;
-
-        do  {
-            if ((pOD->fOptState & OPTST_OMITTED) != 0)
-                continue;
-
-            if ((pOD->fOptState & OPTST_DOCUMENT) != 0) {
-                if (exitCode == EXIT_SUCCESS) {
-                    fprintf(option_usage_fp, argTypes.pzBrk, pOD->pzText,
-                            pOptTitle);
-                    docCt++;
-                }
-
-                continue;
-            }
+        if (checkGNUUsage(pOptions)) {
+            int flen = setGnuOptFmts( pOptions, &pOptTitle );
+            sprintf( zOptFmtLine, zFmtFmt, flen );
+            fputc( '\n', option_usage_fp );
+        }
+        else {
+            int flen = setStdOptFmts( pOptions, &pOptTitle );
+            sprintf( zOptFmtLine, zFmtFmt, flen );
 
             /*
-             *  IF       this is the first auto-opt maintained option
-             *    *AND*  we are doing a full help
-             *    *AND*  there are documentation options
-             *    *AND*  the last one was not a doc option,
-             *  THEN document that the remaining options are not user opts
+             *  When we exit with EXIT_SUCCESS and the first option is a doc
+             *  option, we do *NOT* want to emit the column headers.
+             *  Otherwise, we do.
              */
-            if (  (pOptions->presetOptCt == optNo)
-               && (exitCode == EXIT_SUCCESS)
-               && (docCt > 0)
-               && ((pOD[-1].fOptState & OPTST_DOCUMENT) == 0) )
-                fprintf( option_usage_fp, argTypes.pzBrk, zAuto, pOptTitle );
+            if (  (usage_exit_code != EXIT_SUCCESS)
+               || ((pOptions->pOptDesc->fOptState & OPTST_DOCUMENT) == 0) )
 
-            printBareUsage( pOptions, pOD, &argTypes );
+                fputs( pOptTitle, option_usage_fp );
+        }
 
-            /*
-             *  IF we were invoked because of the --help option,
-             *  THEN print all the extra info
-             */
-            if (exitCode == EXIT_SUCCESS)
-                printExtendedUsage( pOptions, pOD, &argTypes );
-
-        }  while (pOD++, optNo++, (--ct > 0));
+        printOptionUsage( pOptions, usage_exit_code, pOptTitle );
     }
 
-    fputc( '\n', option_usage_fp );
-
     /*
      *  Describe the mechanics of denoting the options
      */
@@ -226,68 +249,16 @@ optionUsage(
      *  IF the user is asking for help (thus exiting with SUCCESS),
      *  THEN see what additional information we can provide.
      */
-    if (exitCode == EXIT_SUCCESS)
+    if (usage_exit_code == EXIT_SUCCESS)
         printProgramDetails( pOptions );
 
     if (pOptions->pzBugAddr != NULL)
         fprintf( option_usage_fp, zPlsSendBugs, pOptions->pzBugAddr );
     fflush( option_usage_fp );
 
-    exit( exitCode );
+    exit( actual_exit_code );
 }
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *   PROGRAM DETAILS
- */
-static void
-printProgramDetails( tOptions* pOptions )
-{
-    ag_bool  initIntro = AG_TRUE;
-
-    /*
-     *  Display all the places we look for config files
-     */
-    printInitList( pOptions->papzHomeList, &initIntro,
-                   pOptions->pzRcName, pOptions->pzProgPath );
-
-    /*
-     *  Let the user know about environment variable settings
-     */
-    if ((pOptions->fOptSet & OPTPROC_ENVIRON) != 0) {
-        if (initIntro)
-            fputs( zPresetIntro, option_usage_fp );
-
-        fprintf( option_usage_fp, zExamineFmt, pOptions->pzPROGNAME );
-    }
-
-    /*
-     *  IF we found an enumeration,
-     *  THEN hunt for it again.  Call the handler proc with a NULL
-     *       option struct pointer.  That tells it to display the keywords.
-     */
-    if (displayEnum) {
-        int        ct     = pOptions->optCt;
-        int        optNo  = 0;
-        tOptDesc*  pOD    = pOptions->pOptDesc;
-
-        fputc( '\n', option_usage_fp );
-        fflush( option_usage_fp );
-        do  {
-            switch (OPTST_GET_ARGTYPE(pOD->fOptState)) {
-            case OPARG_TYPE_ENUMERATION:
-            case OPARG_TYPE_MEMBERSHIP:
-                (*(pOD->pOptProc))( NULL, pOD );
-            }
-        }  while (pOD++, optNo++, (--ct > 0));
-    }
-
-    /*
-     *  If there is a detail string, now is the time for that.
-     */
-    if (pOptions->pzDetail != NULL)
-        fputs( pOptions->pzDetail, option_usage_fp );
-}
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -381,12 +352,15 @@ printExtendedUsage(
     /*
      *  IF this particular option can NOT be preset
      *    AND some form of presetting IS allowed,
+     *    AND it is not an auto-managed option (e.g. --help, et al.)
      *  THEN advise that this option may not be preset.
      */
     if (  ((pOD->fOptState & OPTST_NO_INIT) != 0)
        && (  (pOptions->papzHomeList != NULL)
           || (pOptions->pzPROGNAME != NULL)
-       )  )
+          )
+       && (pOD->optIndex < pOptions->presetOptCt)
+       )
 
         fputs( zNoPreset, option_usage_fp );
 
@@ -423,8 +397,66 @@ printExtendedUsage(
 }
 
 
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ *
+ *   Figure out where all the initialization files might live.
+ *   This requires translating some environment variables and
+ *   testing to see if a name is a directory or a file.  It's
+ *   squishy, but important to tell users how to find these files.
+ */
 static void
-printBareUsage(
+printInitList(
+    tCC* const* papz,
+    ag_bool*    pInitIntro,
+    tCC*        pzRc,
+    tCC*        pzPN )
+{
+    char zPath[ AG_PATH_MAX+1 ];
+
+    if (papz == NULL)
+        return;
+
+    fputs( zPresetIntro, option_usage_fp );
+    *pInitIntro = AG_FALSE;
+
+    for (;;) {
+        char const* pzPath = *(papz++);
+
+        if (pzPath == NULL)
+            break;
+
+        if (optionMakePath(zPath, (int)sizeof( zPath ), pzPath, pzPN))
+            pzPath = zPath;
+
+        /*
+         *  Print the name of the "homerc" file.  If the "rcfile" name is
+         *  not empty, we may or may not print that, too...
+         */
+        fprintf( option_usage_fp, zPathFmt, pzPath );
+        if (*pzRc != NUL) {
+            struct stat sb;
+
+            /*
+             *  IF the "homerc" file is a directory,
+             *  then append the "rcfile" name.
+             */
+            if (  (stat( pzPath, &sb ) == 0)
+              &&  S_ISDIR( sb.st_mode ) ) {
+                fputc( DIRCH, option_usage_fp );
+                fputs( pzRc, option_usage_fp );
+            }
+        }
+
+        fputc( '\n', option_usage_fp );
+    }
+}
+
+
+/*
+ *  Print the usage information for a single option.
+ */
+static void
+printOneUsage(
     tOptions*     pOptions,
     tOptDesc*     pOD,
     arg_types_t*  pAT )
@@ -457,20 +489,18 @@ printBareUsage(
          *  when the option argument is required, base the type string on the
          *  argument type.
          */
-        if (OPTST_GET_ARGTYPE(pOD->fOptState) == OPARG_TYPE_NONE) {
-            pzArgType = pAT->pzNo;
-
-        } else if (pOD->fOptState & OPTST_ARG_OPTIONAL) {
+        if (pOD->fOptState & OPTST_ARG_OPTIONAL) {
             pzArgType = pAT->pzOpt;
 
         } else switch (OPTST_GET_ARGTYPE(pOD->fOptState)) {
+        case OPARG_TYPE_NONE:        pzArgType = pAT->pzNo;   break;
         case OPARG_TYPE_ENUMERATION: pzArgType = pAT->pzKey;  break;
         case OPARG_TYPE_MEMBERSHIP:  pzArgType = pAT->pzKeyL; break;
         case OPARG_TYPE_BOOLEAN:     pzArgType = pAT->pzBool; break;
         case OPARG_TYPE_NUMERIC:     pzArgType = pAT->pzNum;  break;
         case OPARG_TYPE_HIERARCHY:   pzArgType = pAT->pzNest; break;
         case OPARG_TYPE_STRING:      pzArgType = pAT->pzStr;  break;
-        default:                     goto bogus_desc;         break;
+        default:                     goto bogus_desc;
         }
 
         snprintf( z, sizeof(z), pAT->pzOptFmt, pzArgType, pOD->pz_Name,
@@ -488,9 +518,120 @@ printBareUsage(
 
  bogus_desc:
     fprintf( stderr, zInvalOptDesc, pOD->pz_Name );
-    exit( EXIT_FAILURE );
+    exit( EX_SOFTWARE );
 }
 
+
+/*
+ *  Print out the usage information for just the options.
+ */
+static void
+printOptionUsage(
+    tOptions* pOpts,
+    int       ex_code,
+    tCC*      pOptTitle )
+{
+    int        ct     = pOpts->optCt;
+    int        optNo  = 0;
+    tOptDesc*  pOD    = pOpts->pOptDesc;
+    int        docCt  = 0;
+
+    do  {
+        if ((pOD->fOptState & OPTST_OMITTED) != 0)
+            continue;
+
+        if ((pOD->fOptState & OPTST_DOCUMENT) != 0) {
+            if (ex_code == EXIT_SUCCESS) {
+                fprintf(option_usage_fp, argTypes.pzBrk, pOD->pzText,
+                        pOptTitle);
+                docCt++;
+            }
+
+            continue;
+        }
+
+        /*
+         *  IF       this is the first auto-opt maintained option
+         *    *AND*  we are doing a full help
+         *    *AND*  there are documentation options
+         *    *AND*  the last one was not a doc option,
+         *  THEN document that the remaining options are not user opts
+         */
+        if (  (pOpts->presetOptCt == optNo)
+              && (ex_code == EXIT_SUCCESS)
+              && (docCt > 0)
+              && ((pOD[-1].fOptState & OPTST_DOCUMENT) == 0) )
+            fprintf( option_usage_fp, argTypes.pzBrk, zAuto, pOptTitle );
+
+        printOneUsage( pOpts, pOD, &argTypes );
+
+        /*
+         *  IF we were invoked because of the --help option,
+         *  THEN print all the extra info
+         */
+        if (ex_code == EXIT_SUCCESS)
+            printExtendedUsage( pOpts, pOD, &argTypes );
+
+    }  while (pOD++, optNo++, (--ct > 0));
+
+    fputc( '\n', option_usage_fp );
+}
+
+
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ *
+ *   PROGRAM DETAILS
+ */
+static void
+printProgramDetails( tOptions* pOptions )
+{
+    ag_bool  initIntro = AG_TRUE;
+
+    /*
+     *  Display all the places we look for config files
+     */
+    printInitList( pOptions->papzHomeList, &initIntro,
+                   pOptions->pzRcName, pOptions->pzProgPath );
+
+    /*
+     *  Let the user know about environment variable settings
+     */
+    if ((pOptions->fOptSet & OPTPROC_ENVIRON) != 0) {
+        if (initIntro)
+            fputs( zPresetIntro, option_usage_fp );
+
+        fprintf( option_usage_fp, zExamineFmt, pOptions->pzPROGNAME );
+    }
+
+    /*
+     *  IF we found an enumeration,
+     *  THEN hunt for it again.  Call the handler proc with a NULL
+     *       option struct pointer.  That tells it to display the keywords.
+     */
+    if (displayEnum) {
+        int        ct     = pOptions->optCt;
+        int        optNo  = 0;
+        tOptDesc*  pOD    = pOptions->pOptDesc;
+
+        fputc( '\n', option_usage_fp );
+        fflush( option_usage_fp );
+        do  {
+            switch (OPTST_GET_ARGTYPE(pOD->fOptState)) {
+            case OPARG_TYPE_ENUMERATION:
+            case OPARG_TYPE_MEMBERSHIP:
+                (*(pOD->pOptProc))( NULL, pOD );
+            }
+        }  while (pOD++, optNo++, (--ct > 0));
+    }
+
+    /*
+     *  If there is a detail string, now is the time for that.
+     */
+    if (pOptions->pzDetail != NULL)
+        fputs( pOptions->pzDetail, option_usage_fp );
+}
+
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *   OPTION LINE FORMATTING SETUP
@@ -502,8 +643,48 @@ printBareUsage(
  *      on the command line.
  *  These formats are used immediately after the option flag (if used) has
  *  been printed.
+ *
+ *  Set up the formatting for GNU-style output
  */
-static void
+static int
+setGnuOptFmts( tOptions* pOpts, tCC** ppT )
+{
+    int  flen = 22;
+    *ppT = zNoRq_ShrtTtl;
+
+    argTypes.pzStr  = zGnuStrArg;
+    argTypes.pzReq  = zOneSpace;
+    argTypes.pzNum  = zGnuNumArg;
+    argTypes.pzKey  = zGnuKeyArg;
+    argTypes.pzKeyL = zGnuKeyLArg;
+    argTypes.pzBool = zGnuBoolArg;
+    argTypes.pzNest = zGnuNestArg;
+    argTypes.pzOpt  = zGnuOptArg;
+    argTypes.pzNo   = zOneSpace;
+    argTypes.pzBrk  = zGnuBreak;
+    argTypes.pzNoF  = zSixSpaces;
+    argTypes.pzSpc  = zThreeSpaces;
+
+    switch (pOpts->fOptSet & OPTPROC_L_N_S) {
+    case OPTPROC_L_N_S:    argTypes.pzOptFmt = zGnuOptFmt;     break;
+    case OPTPROC_LONGOPT:  argTypes.pzOptFmt = zGnuOptFmt;     break;
+    case 0:                argTypes.pzOptFmt = zGnuOptFmt + 2; break;
+    case OPTPROC_SHORTOPT:
+        argTypes.pzOptFmt = zShrtGnuOptFmt;
+        zGnuStrArg[0] = zGnuNumArg[0] = zGnuKeyArg[0] = zGnuBoolArg[0] = ' ';
+        argTypes.pzOpt = " [arg]";
+        flen = 8;
+        break;
+    }
+
+    return flen;
+}
+
+
+/*
+ *  Standard (AutoOpts normal) option line formatting
+ */
+static int
 setStdOptFmts( tOptions* pOpts, tCC** ppT )
 {
     int  flen = 0;
@@ -546,102 +727,14 @@ setStdOptFmts( tOptions* pOpts, tCC** ppT )
         flen = 24;
     }
 
-    sprintf( zOptFmtLine, zFmtFmt, flen );
+    return flen;
 }
 
-static void
-setGnuOptFmts( tOptions* pOpts, tCC** ppT )
-{
-    int  flen = 22;
-    *ppT = zNoRq_ShrtTtl;
 
-    argTypes.pzStr  = zGnuStrArg;
-    argTypes.pzReq  = zOneSpace;
-    argTypes.pzNum  = zGnuNumArg;
-    argTypes.pzKey  = zGnuKeyArg;
-    argTypes.pzKeyL = zGnuKeyLArg;
-    argTypes.pzBool = zGnuBoolArg;
-    argTypes.pzNest = zGnuNestArg;
-    argTypes.pzOpt  = zGnuOptArg;
-    argTypes.pzNo   = zOneSpace;
-    argTypes.pzBrk  = zGnuBreak;
-    argTypes.pzNoF  = zSixSpaces;
-    argTypes.pzSpc  = zThreeSpaces;
-
-    switch (pOpts->fOptSet & OPTPROC_L_N_S) {
-    case OPTPROC_L_N_S:    argTypes.pzOptFmt = zGnuOptFmt;     break;
-    case OPTPROC_LONGOPT:  argTypes.pzOptFmt = zGnuOptFmt;     break;
-    case 0:                argTypes.pzOptFmt = zGnuOptFmt + 2; break;
-    case OPTPROC_SHORTOPT:
-        argTypes.pzOptFmt = zShrtGnuOptFmt;
-        zGnuStrArg[0] = zGnuNumArg[0] = zGnuKeyArg[0] = zGnuBoolArg[0] = ' ';
-        argTypes.pzOpt = " [arg]";
-        flen = 8;
-        break;
-    }
-
-    sprintf( zOptFmtLine, zFmtFmt, flen );
-}
-
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *   Figure out where all the initialization files might live.
- *   This requires translating some environment variables and
- *   testing to see if a name is a directory or a file.  It's
- *   squishy, but important to tell users how to find these files.
- */
-static void
-printInitList(
-    tCC**    papz,
-    ag_bool* pInitIntro,
-    tCC*     pzRc,
-    tCC*     pzPN )
-{
-    char zPath[ MAXPATHLEN+1 ];
-
-    if (papz == NULL)
-        return;
-
-    fputs( zPresetIntro, option_usage_fp );
-    *pInitIntro = AG_FALSE;
-
-    for (;;) {
-        const char* pzPath = *(papz++);
-
-        if (pzPath == NULL)
-            break;
-
-        if (optionMakePath( zPath, sizeof( zPath ), pzPath, pzPN ))
-            pzPath = zPath;
-
-        /*
-         *  Print the name of the "homerc" file.  If the "rcfile" name is
-         *  not empty, we may or may not print that, too...
-         */
-        fprintf( option_usage_fp, zPathFmt, pzPath );
-        if (*pzRc != NUL) {
-            struct stat sb;
-
-            /*
-             *  IF the "homerc" file is a directory,
-             *  then append the "rcfile" name.
-             */
-            if (  (stat( pzPath, &sb ) == 0)
-              &&  S_ISDIR( sb.st_mode ) ) {
-                fputc( '/', option_usage_fp );
-                fputs( pzRc, option_usage_fp );
-            }
-        }
-
-        fputc( '\n', option_usage_fp );
-    }
-}
-
-/*
+/*:
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/usage.c */
