@@ -1,12 +1,28 @@
 /*
- *  $Id: gdinit.c,v 4.7 2006/11/27 01:52:23 bkorb Exp $
+ *  $Id: gdinit.c,v 4.9 2007/07/04 20:51:19 bkorb Exp $
  *
- *    getdefs copyright 1999-2006 Bruce Korb
+ *    getdefs copyright 1999-2007 Bruce Korb
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Time-stamp:        "2006-11-26 16:44:07 bkorb"
- *  Last Modified:     $Date: 2006/11/27 01:52:23 $
+ *  Time-stamp:        "2007-07-04 11:57:21 bkorb"
+ *  Last Modified:     $Date: 2007/07/04 20:51:19 $
  *            by: bkorb
+ *
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 Bruce Korb - all rights reserved
+ *
+ *  AutoGen is free software: you can redistribute it and/or modify it
+ *  under the terms of the GNU General Public License as published by the
+ *  Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  AutoGen is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *  See the GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 tSCC zNoList[] = "ERROR:  block attr must have name list:\n\t%s\n";
@@ -368,7 +384,7 @@ validateOptions( void )
      *       IF we cannot load the file,
      *       THEN it must be new or empty.  Allocate several K to start.
      */
-    if (   HAVE_OPT( ORDERING )
+    if (  HAVE_OPT( ORDERING )
        && (OPT_ARG( ORDERING ) != NULL)) {
         tSCC zIndexPreamble[] =
             "# -*- buffer-read-only: t -*- vi: set ro:\n"
@@ -392,11 +408,15 @@ validateOptions( void )
         strequate( "_-^" );
     }
 
-    if (OPT_ARG( SRCFILE ) == NULL)
-        OPT_ARG( SRCFILE ) = "srcfile";
+    {
+        char const * pz = OPT_ARG( SRCFILE );
+        if ((pz == NULL) || (*pz == NUL))
+            OPT_ARG( SRCFILE ) = "srcfile";
 
-    if (OPT_ARG( LINENUM ) == NULL)
-        OPT_ARG( LINENUM ) = "linenum";
+        pz = OPT_ARG( LINENUM );
+        if ((pz == NULL) || (*pz == NUL))
+            OPT_ARG( LINENUM ) = "linenum";
+    }
 
     {
         tSCC zAgNameChars[] = "abcdefghijklmnopqrstuvwxyz"
