@@ -1,12 +1,26 @@
 /*
- *  $Id: getdefs.c,v 4.8 2006/11/27 01:52:23 bkorb Exp $
+ *  $Id: getdefs.c,v 4.10 2007/07/04 20:51:19 bkorb Exp $
  *
- *    getdefs copyright 1999-2006 Bruce Korb
+ *    getdefs copyright 1999-2007 Bruce Korb
  *
- *  Time-stamp:        "2006-11-26 16:42:14 bkorb"
+ *  Time-stamp:        "2007-07-04 11:57:32 bkorb"
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Maintainer:        Bruce Korb <bkorb@gnu.org>
- *  Created:           Mon Jun 30 15:35:12 1997
+ *
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 Bruce Korb - all rights reserved
+ *
+ *  AutoGen is free software: you can redistribute it and/or modify it
+ *  under the terms of the GNU General Public License as published by the
+ *  Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  AutoGen is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *  See the GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 tSCC zBogusDef[] = "Bogus definition:\n%s\n";
@@ -612,7 +626,7 @@ doPreamble( FILE* outFp )
         tSCC   zFmt[] = "%-12s = '%s';\n";
         tCC*   pzName = OPT_ARG( FILELIST );
 
-        if (pzName == NULL)
+        if ((pzName == NULL) || (*pzName == NUL))
             pzName = "infile";
 
         if (HAVE_OPT( INPUT )) {
