@@ -1,11 +1,25 @@
 #! /bin/sh
 
 ## mkgnudoc.sh --   create a native package
-## Copyright (c):   2003-2007 by Bruce Korb
-## Time-stamp:      "2007-02-04 10:08:03 bkorb"
-##              by: bkorb
+## Time-stamp:      "2007-07-04 11:58:07 bkorb"
+##
+##  This file is part of AutoGen.
+##  AutoGen copyright (c) 1992-2007 Bruce Korb - all rights reserved
+##
+##  AutoGen is free software: you can redistribute it and/or modify it
+##  under the terms of the GNU General Public License as published by the
+##  Free Software Foundation, either version 3 of the License, or
+##  (at your option) any later version.
+##
+##  AutoGen is distributed in the hope that it will be useful, but
+##  WITHOUT ANY WARRANTY; without even the implied warranty of
+##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+##  See the GNU General Public License for more details.
+##
+##  You should have received a copy of the GNU General Public License along
+##  with this program.  If not, see <http://www.gnu.org/licenses/>.
 ## ---------------------------------------------------------------------
-## $Id: mkgnudoc.sh,v 4.8 2007/02/04 18:51:52 bkorb Exp $
+## $Id: mkgnudoc.sh,v 4.11 2007/07/04 20:51:19 bkorb Exp $
 ## ---------------------------------------------------------------------
 ## Code:
 
@@ -15,7 +29,7 @@ test -f ${scriptdir}/pkg-env && . ${scriptdir}/pkg-env
 MAKE=${MAKE:-make}
 pkgsrcdir=`dirname $0`
 pkgsrcdir=`cd ${pkgsrcdir} ; pwd`
-pkg=autogen
+pkg=${PACKAGE_TARNAME}
 ver="${PACKAGE_VERSION}"
 
 set -x
@@ -106,6 +120,7 @@ autogen --base-name=${pkg} -T ${pkgsrcdir}/gnudoc.tpl - <<- _EODefs_
 	title   = '${PACKAGE} - ${*}';
 	project = '${PACKAGE}';
 	version = '${ver}';
+	package = '${pkg}';
 	_EODefs_
 
 rm -f TAG
