@@ -367,81 +367,76 @@ parse_printf_format (const char *format, int n, int *argtypes)
   while (*info.format != EOS)
     {
       int ch = (int) *info.format++;
+      spec_entry *spec;
+      int status;
+      int argindex;
 
-      switch (ch)
-	{
-	case SNV_CHAR_SPEC:
-	  if (*info.format != SNV_CHAR_SPEC)
-	    {
-	      /* We found the start of a format specifier! */
-	      spec_entry *spec;
-	      int status;
-	      int argindex;
-
-	      parser_reset (&info);
-	      do
-		{
-		  /* Until we fill the stream (or get some other
-		     exception) or one of the handlers tells us
-		     we have reached the end of the specifier... */
-
-		  /* ...lookup the handler associated with the char
-		     we are looking at in the format string... */
-		  spec = spec_lookup ((unsigned)*(info.format));
-		  if (spec == NULL)
-		    {
-		      PRINTF_ERROR (&info, "unregistered specifier");
-		      goto error;
-		    }
-
-		  if (!IS_MODIFIER (spec) &&
-		      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
-		    {
-		      PRINTF_ERROR (&info, "invalid combination of flags");
-		      goto error;
-		    }
-
-	          argindex = info.dollar && !IS_MODIFIER (spec)
-			       ? info.dollar - 1 : info.argindex;
-
-                  /* ...and call the relevant handler.  */
-                  if (spec->arg)
-                    {
-                      info.spec = (unsigned)*(info.format);
-                      info.extra = spec->user;
-                      info.type = spec->type;
-                      status = (*spec->arg) (&info, (size_t) (n - argindex),
-                                             argtypes + argindex);
-                    }
-                  else
-                    {
-                      status = 1;
-                      if (n > argindex)
-                        argtypes[argindex] = spec->type;
-                    }
-
-                  if (status < 0)
-                    goto error;
-
-                  info.argc = MAX (info.argc, argindex + status);
-                  if (!info.dollar || !IS_MODIFIER (spec))
-                    info.argindex += status;
-
-                  info.format++;
-                }
-              while (IS_MODIFIER (spec));
-              continue;
-            }
+      if (ch != SNV_CHAR_SPEC)
+        continue;
 
+      if (*info.format == SNV_CHAR_SPEC)
+        {
           /* An escaped CHAR_SPEC: ignore it (by falling through). */
           ++info.format;
-
-          /*FALLTHROUGH*/
-
-        default:        /* Just a character: ignore it. */
           continue;
         }
 
+      /* We found the start of a format specifier! */
+      parser_reset (&info);
+      do
+        {
+          /* Until we fill the stream (or get some other
+             exception) or one of the handlers tells us
+             we have reached the end of the specifier... */
+
+          /* ...lookup the handler associated with the char
+             we are looking at in the format string... */
+          spec = spec_lookup ((unsigned)*(info.format));
+          if (spec == NULL)
+            {
+              PRINTF_ERROR (&info, "unregistered specifier");
+              goto error;
+            }
+
+          if (!IS_MODIFIER (spec) &&
+              !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
+            {
+              PRINTF_ERROR (&info, "invalid combination of flags");
+              goto error;
+            }
+
+          argindex = info.dollar && !IS_MODIFIER (spec)
+            ? info.dollar - 1 : info.argindex;
+
+          /* ...and call the relevant handler.  */
+          if (spec->arg)
+            {
+              info.spec = (unsigned)*(info.format);
+              info.extra = spec->user;
+              info.type = spec->type;
+              status = (*spec->arg) (&info, (size_t) (n - argindex),
+                                     argtypes + argindex);
+            }
+          else
+            {
+              status = 1;
+              if (n > argindex)
+                argtypes[argindex] = spec->type;
+            }
+
+          if (status < 0)
+            goto error;
+
+          info.argc = MAX (info.argc, argindex + status);
+          if (!info.dollar || !IS_MODIFIER (spec))
+            info.argindex += status;
+
+          info.format++;
+        }
+      while (IS_MODIFIER (spec));
+
+      continue;
+
     error:
       /* Get here on error */
       info.argc = -1;
